==> haskell-openssl-streams-1.2.2.0-57-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-openssl-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 openssl-streams
version:              1.2.2.0
visibility:           public
id:                   openssl-streams-1.2.2.0-EEz8yRLoDVF4TTWKR0HLP
key:                  openssl-streams-1.2.2.0-EEz8yRLoDVF4TTWKR0HLP
license:              BSD-3-Clause
maintainer:           Gregory Collins <greg@gregorycollins.net>
synopsis:             OpenSSL network support for io-streams.
description:
    The openssl-streams library contains io-streams routines for secure
    networking using OpenSSL (by way of HsOpenSSL).

category:             Network, IO-Streams
abi:                  55cf8532eb39b60424625e6da57cee03
exposed:              True
exposed-modules:      System.IO.Streams.SSL
import-dirs:          /usr/lib/ghc-8.8.3/site-local/openssl-streams-1.2.2.0
library-dirs:         /usr/lib/ghc-8.8.3/site-local/openssl-streams-1.2.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/openssl-streams-1.2.2.0
hs-libraries:         HSopenssl-streams-1.2.2.0-EEz8yRLoDVF4TTWKR0HLP
depends:
    HsOpenSSL-0.11.4.18-G2sUv7265TXhBkKc6gr5u base-4.13.0.0
    bytestring-0.10.10.0 io-streams-1.5.1.0-4rGtcLxNjv0EN91DmPMquu
    network-3.1.1.1-5FgtrTFHUQaFQhXHTS1i9u

haddock-interfaces:
    /usr/share/doc/haskell-openssl-streams/html/openssl-streams.haddock

haddock-html:         /usr/share/doc/haskell-openssl-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-openssl-streams-1.2.2.0-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-openssl-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 openssl-streams
version:              1.2.2.0
visibility:           public
id:                   openssl-streams-1.2.2.0-D8F7NRKzD5sHpnPq7Ad9NI
key:                  openssl-streams-1.2.2.0-D8F7NRKzD5sHpnPq7Ad9NI
license:              BSD-3-Clause
maintainer:           Gregory Collins <greg@gregorycollins.net>
synopsis:             OpenSSL network support for io-streams.
description:
    The openssl-streams library contains io-streams routines for secure
    networking using OpenSSL (by way of HsOpenSSL).

category:             Network, IO-Streams
abi:                  0a715360e70b8c739d0bfb4b8cb01694
exposed:              True
exposed-modules:      System.IO.Streams.SSL
import-dirs:          /usr/lib/ghc-8.10.1/site-local/openssl-streams-1.2.2.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/openssl-streams-1.2.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/openssl-streams-1.2.2.0
hs-libraries:         HSopenssl-streams-1.2.2.0-D8F7NRKzD5sHpnPq7Ad9NI
depends:
    HsOpenSSL-0.11.4.18-5JRH8CCKzq55icBl44PvxX base-4.14.0.0
    bytestring-0.10.10.0 io-streams-1.5.1.0-DamGv8a3avHK1aY1VYaG71
    network-3.1.1.1-I205ehn629wJW4axo8gUI9

haddock-interfaces:
    /usr/share/doc/haskell-openssl-streams/html/openssl-streams.haddock

haddock-html:         /usr/share/doc/haskell-openssl-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
